Command Line Interface
======================
semra automatically installs the command :code:`semra`. See
:code:`semra --help` for usage details.

.. click:: semra.cli:main
   :prog: semra
   :show-nested:
